<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en_US">
<context>
    <name>AboutDialog</name>
    <message>
        <source>A feature-rich YouTube client for the Nokia N900. This is an experimental release using QML. &lt;br&gt;&lt;br&gt; &amp;copy; Stuart Howarth 2011</source>
        <translation type="obsolete">Een YouTube client voor de Nokia N900.  Dit is een experimentele versie met behulp van QML. &lt;br&gt;&lt;br&gt; &amp;copy; Stuart Howarth 2011</translation>
    </message>
    <message>
        <location filename="../AboutDialog.qml" line="44"/>
        <source>cuteTube-QML - 0.9.4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../AboutDialog.qml" line="56"/>
        <source>A feature-rich YouTube client enabling browsing, playback and download of videos, plus account management. &lt;br&gt;&lt;br&gt; &amp;copy; Stuart Howarth 2011</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AccountDetailsDialog</name>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="10"/>
        <location filename="../AccountDetailsDialog.qml" line="26"/>
        <source>New Account</source>
        <translation>Nieuw Account</translation>
    </message>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="15"/>
        <source>Edit Account</source>
        <translation>Verander Account</translation>
    </message>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="46"/>
        <source>Database error. Unable to save account</source>
        <translation>Database fout. Kan account niet opslaan</translation>
    </message>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="82"/>
        <source>Username</source>
        <translation>Gebruikersnaam</translation>
    </message>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="94"/>
        <source>Password</source>
        <translation>Wachtwoord</translation>
    </message>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="107"/>
        <source>Default?</source>
        <translation>Standaard?</translation>
    </message>
</context>
<context>
    <name>AccountsDialog</name>
    <message>
        <location filename="../AccountsDialog.qml" line="35"/>
        <source>Database error. Unable to delete account</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../AccountsDialog.qml" line="79"/>
        <source>YouTube Accounts</source>
        <translation>YouTube Accounts</translation>
    </message>
</context>
<context>
    <name>AddCommentDialog</name>
    <message>
        <location filename="../AddCommentDialog.qml" line="6"/>
        <source>Add Comment</source>
        <translation>Voeg Commentaar toe</translation>
    </message>
    <message>
        <location filename="../AddCommentDialog.qml" line="15"/>
        <source>Share Via </source>
        <translation>Delen Via </translation>
    </message>
    <message>
        <location filename="../AddCommentDialog.qml" line="60"/>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <location filename="../AddCommentDialog.qml" line="74"/>
        <source>Description</source>
        <translation>Beschrijving</translation>
    </message>
    <message>
        <location filename="../AddCommentDialog.qml" line="111"/>
        <source>Message</source>
        <translation>Bericht</translation>
    </message>
</context>
<context>
    <name>AddToPlaylistDialog</name>
    <message>
        <location filename="../AddToPlaylistDialog.qml" line="31"/>
        <source>Add To Playlist</source>
        <translation>Voeg toe aan Afspeellijst</translation>
    </message>
</context>
<context>
    <name>ArchiveListView</name>
    <message>
        <source>Delete from archive</source>
        <translation type="obsolete">Verwijder uit archief</translation>
    </message>
    <message>
        <source>Delete from device</source>
        <translation type="obsolete">Verwijder van toestel</translation>
    </message>
    <message>
        <location filename="../ArchiveListView.qml" line="93"/>
        <source>Deleted from archive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ArchiveListView.qml" line="96"/>
        <location filename="../ArchiveListView.qml" line="116"/>
        <source>Unable to delete from archive</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BusyDialog</name>
    <message>
        <location filename="../BusyDialog.qml" line="45"/>
        <source>Loading...</source>
        <translation>Laden...</translation>
    </message>
</context>
<context>
    <name>ChangeUserDialog</name>
    <message>
        <location filename="../ChangeUserDialog.qml" line="50"/>
        <source>Change Current User</source>
        <translation>Verander Huidige Gebruiker</translation>
    </message>
</context>
<context>
    <name>CommentsDelegate</name>
    <message>
        <location filename="../CommentsDelegate.qml" line="19"/>
        <location filename="../CommentsDelegate.qml" line="21"/>
        <source>By </source>
        <translation>Door </translation>
    </message>
    <message>
        <location filename="../CommentsDelegate.qml" line="20"/>
        <location filename="../CommentsDelegate.qml" line="22"/>
        <source> on </source>
        <translation> op </translation>
    </message>
</context>
<context>
    <name>ConfirmDeleteDialog</name>
    <message>
        <location filename="../ConfirmDeleteDialog.qml" line="30"/>
        <source>Confirm Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ConfirmDeleteDialog.qml" line="42"/>
        <source>Please choose from where you wish to delete the selected videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ConfirmDeleteDialog.qml" line="55"/>
        <source>Archive</source>
        <translation type="unfinished">Archief</translation>
    </message>
    <message>
        <location filename="../ConfirmDeleteDialog.qml" line="65"/>
        <source>Device</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfirmExitDialog</name>
    <message>
        <location filename="../ConfirmExitDialog.qml" line="47"/>
        <source>Hold it!</source>
        <translation>Wachten!</translation>
    </message>
    <message>
        <location filename="../ConfirmExitDialog.qml" line="58"/>
        <source>cuteTube is currently downloading. Do you really want to exit?</source>
        <translation>cuteTube is aan het downloaden. Weet je zeker dat je wil afsluiten?</translation>
    </message>
    <message>
        <location filename="../ConfirmExitDialog.qml" line="71"/>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <location filename="../ConfirmExitDialog.qml" line="81"/>
        <source>No</source>
        <translation>Nee</translation>
    </message>
</context>
<context>
    <name>Controller</name>
    <message>
        <source>English</source>
        <translation type="obsolete">Engels</translation>
    </message>
    <message>
        <source>German</source>
        <translation type="obsolete">Duits</translation>
    </message>
    <message>
        <source>Italian</source>
        <translation type="obsolete">Italiaans</translation>
    </message>
    <message>
        <source>Finnish</source>
        <translation type="obsolete">Fins</translation>
    </message>
    <message>
        <source>Dutch</source>
        <translation type="obsolete">Nederlands</translation>
    </message>
    <message>
        <source>Polish</source>
        <translation type="obsolete">Pools</translation>
    </message>
    <message>
        <location filename="../../../controller.cpp" line="253"/>
        <source>Video deleted from device</source>
        <translation>Video verwijderd van telefoon</translation>
    </message>
    <message>
        <location filename="../../../controller.cpp" line="256"/>
        <source>Unable to delete video</source>
        <translation>Kan video niet verwijderen</translation>
    </message>
    <message>
        <location filename="../../../controller.cpp" line="260"/>
        <source>Video not found</source>
        <translation>Video niet gevonden</translation>
    </message>
    <message>
        <location filename="../../../controller.cpp" line="315"/>
        <source>Copied to clipboard</source>
        <translation>Gekopieerd naar het klembord</translation>
    </message>
</context>
<context>
    <name>DownloadListDelegate</name>
    <message>
        <source>Paused</source>
        <translation type="obsolete">onderbroken</translation>
    </message>
    <message>
        <source>Queued</source>
        <translation type="obsolete">Wachtrij</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation type="obsolete">Mislukt</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation type="obsolete">Downloaden</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>Failed</source>
        <translation type="obsolete">Mislukt</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation type="obsolete">Downloaden</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation type="obsolete">Onderbroken</translation>
    </message>
</context>
<context>
    <name>FileChooserDialog</name>
    <message>
        <location filename="../FileChooserDialog.qml" line="29"/>
        <source>Choose Video File</source>
        <translation>Kies een Video Bestand</translation>
    </message>
</context>
<context>
    <name>HomeView</name>
    <message>
        <source>Settings</source>
        <translation type="obsolete">Instellingen</translation>
    </message>
    <message>
        <source>About</source>
        <translation type="obsolete">Info</translation>
    </message>
    <message>
        <location filename="../HomeView.qml" line="115"/>
        <source>My Channel</source>
        <translation>Mijn Kanaal</translation>
    </message>
    <message>
        <source>Most Recent</source>
        <translation type="obsolete">Meest Recente</translation>
    </message>
    <message>
        <source>Most Viewed</source>
        <translation type="obsolete">Meest Bekeken</translation>
    </message>
    <message>
        <location filename="../HomeView.qml" line="185"/>
        <source>Archive</source>
        <translation>Archief</translation>
    </message>
</context>
<context>
    <name>InboxDelegate</name>
    <message>
        <location filename="../InboxDelegate.qml" line="44"/>
        <location filename="../InboxDelegate.qml" line="46"/>
        <source>From </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../InboxDelegate.qml" line="45"/>
        <location filename="../InboxDelegate.qml" line="47"/>
        <location filename="../InboxDelegate.qml" line="95"/>
        <source> on </source>
        <translation type="unfinished"> op </translation>
    </message>
    <message>
        <location filename="../InboxDelegate.qml" line="95"/>
        <source>By </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../InboxDelegate.qml" line="145"/>
        <source>Views</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>InboxDialog</name>
    <message>
        <location filename="../InboxDialog.qml" line="57"/>
        <source>Inbox</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../InboxDialog.qml" line="69"/>
        <source>No messages found</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MenuBar</name>
    <message>
        <source>Back</source>
        <translation type="obsolete">Terug</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="obsolete">Afsluiten</translation>
    </message>
    <message>
        <location filename="../MenuBar.qml" line="150"/>
        <source>Sort</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MyAccountView</name>
    <message>
        <location filename="../MyAccountView.qml" line="91"/>
        <source>My Uploads</source>
        <translation>Mijn Uploads</translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="97"/>
        <source>Uploads</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="115"/>
        <source>My Favourites</source>
        <translation>Mijn Favorieten</translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="121"/>
        <source>Favourites</source>
        <translation>Favorieten</translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="145"/>
        <source>Playlists</source>
        <translation>Afspeellijst</translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="169"/>
        <source>Subscriptions</source>
        <translation>Abonnementen</translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="184"/>
        <source>Signed in as:</source>
        <translation>Ingelogd als:</translation>
    </message>
</context>
<context>
    <name>NewPlaylistDialog</name>
    <message>
        <location filename="../NewPlaylistDialog.qml" line="34"/>
        <source>New Playlist</source>
        <translation>Nieuwe Afspeellijst</translation>
    </message>
    <message>
        <location filename="../NewPlaylistDialog.qml" line="46"/>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <location filename="../NewPlaylistDialog.qml" line="59"/>
        <source>Description (optional)</source>
        <translation>Beschrijving (optioneel)</translation>
    </message>
    <message>
        <location filename="../NewPlaylistDialog.qml" line="71"/>
        <source>Private?</source>
        <translation>Prive?</translation>
    </message>
</context>
<context>
    <name>NoAccountDialog</name>
    <message>
        <location filename="../NoAccountDialog.qml" line="60"/>
        <source>Hi there!</source>
        <translation>Hallo daar!</translation>
    </message>
    <message>
        <location filename="../NoAccountDialog.qml" line="71"/>
        <source>My name&apos;s Cutey. My buddy Clippy tells me it&apos;s the first time you&apos;ve used cuteTube. Would you like to add a YouTube account?</source>
        <translation>Mijn naam is Cutey. Mijn vriend Clippy vertelde me dat dit je eerste keer is dat je cuteTube gebruikt. Wil je een YouTube account toe voegen?</translation>
    </message>
    <message>
        <location filename="../NoAccountDialog.qml" line="84"/>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <location filename="../NoAccountDialog.qml" line="98"/>
        <source>Go Away</source>
        <translation>Ga Weg</translation>
    </message>
</context>
<context>
    <name>NotificationArea</name>
    <message>
        <location filename="../NotificationArea.qml" line="55"/>
        <source>No active downloads</source>
        <translation>Geen actieve downloads</translation>
    </message>
    <message>
        <location filename="../NotificationArea.qml" line="151"/>
        <source>Downloads</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>OAuthDialog</name>
    <message>
        <location filename="../OAuthDialog.qml" line="8"/>
        <source>Authorisation For </source>
        <translation>Bevestigen Voor </translation>
    </message>
    <message>
        <location filename="../OAuthDialog.qml" line="27"/>
        <source>Error obtaining facebook authorisation</source>
        <translation>Er is een fout opgetreden tijdens bevestingen facebook account</translation>
    </message>
    <message>
        <location filename="../OAuthDialog.qml" line="117"/>
        <source>Enter pin code</source>
        <translation>Geef uw pin code</translation>
    </message>
</context>
<context>
    <name>PlaylistDelegate</name>
    <message>
        <location filename="../PlaylistDelegate.qml" line="30"/>
        <source> videos</source>
        <translation> video&apos;s</translation>
    </message>
</context>
<context>
    <name>PlaylistDialog</name>
    <message>
        <location filename="../PlaylistDialog.qml" line="80"/>
        <source>Playlist Info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../PlaylistDialog.qml" line="125"/>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../PlaylistDialog.qml" line="131"/>
        <source>Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../PlaylistDialog.qml" line="151"/>
        <source>Created</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../PlaylistDialog.qml" line="157"/>
        <source>Updated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../PlaylistDialog.qml" line="185"/>
        <source>Description</source>
        <translation type="unfinished">Beschrijving</translation>
    </message>
    <message>
        <location filename="../PlaylistDialog.qml" line="203"/>
        <source>No description</source>
        <translation type="unfinished">Geen beschrijving</translation>
    </message>
    <message>
        <location filename="../PlaylistDialog.qml" line="218"/>
        <source>Play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../PlaylistDialog.qml" line="241"/>
        <source>Download</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PlaylistVideosView</name>
    <message>
        <source>Add to favourites</source>
        <translation type="obsolete">Voeg toe aan favorieten</translation>
    </message>
    <message>
        <source>Add to playlist</source>
        <translation type="obsolete">Voeg toe aan afspeellijst</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation type="obsolete">Kopiëren naar klembord</translation>
    </message>
    <message>
        <location filename="../PlaylistVideosView.qml" line="89"/>
        <source>Video(s) deleted from playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../PlaylistVideosView.qml" line="110"/>
        <source>No videos found</source>
        <translation>Geen video&apos;s gevonden</translation>
    </message>
    <message>
        <location filename="../PlaylistVideosView.qml" line="168"/>
        <source>Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../PlaylistVideosView.qml" line="182"/>
        <source>Updated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../PlaylistVideosView.qml" line="205"/>
        <source>Play all</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../PlaylistVideosView.qml" line="213"/>
        <source>Loading playlist videos. Please wait</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PlaylistsView</name>
    <message>
        <location filename="../PlaylistsView.qml" line="50"/>
        <source>New playlist created</source>
        <translation>Nieuwe afspeellijst gemaakt</translation>
    </message>
    <message>
        <location filename="../PlaylistsView.qml" line="54"/>
        <source>Playlist deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New playlist</source>
        <translation type="obsolete">Nieuwe afspeellijst</translation>
    </message>
    <message>
        <location filename="../PlaylistsView.qml" line="87"/>
        <source>No playlists found</source>
        <translation>Geen afspeellijst gevonden</translation>
    </message>
</context>
<context>
    <name>ProxyDialog</name>
    <message>
        <location filename="../ProxyDialog.qml" line="35"/>
        <source>Network Proxy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ProxyDialog.qml" line="49"/>
        <source>Host (e.g. 192.168.100.1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ProxyDialog.qml" line="56"/>
        <source>Port (e.g. 8080)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Date</source>
        <translation type="obsolete">Datum</translation>
    </message>
    <message>
        <source>Relevance</source>
        <translation type="obsolete">Relevantie</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation type="obsolete">Beoordeling</translation>
    </message>
    <message>
        <source>Views</source>
        <translation type="obsolete">Bekenen</translation>
    </message>
    <message>
        <location filename="../SearchBar.qml" line="185"/>
        <source>Order by:</source>
        <translation>Sorteren op:</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../SettingsDialog.qml" line="217"/>
        <source>Your saved searches have been cleared</source>
        <translation>Uw opgeslagen zoekopdrachten zijn verwijderd</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="220"/>
        <source>Database error. Unable to clear searches</source>
        <translation>Database fout. Kan zoekopdrachten niet verwijderen</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="279"/>
        <source>Settings</source>
        <translation>Instellingen</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="345"/>
        <source>Playback quality</source>
        <translation>Afspeel kwaliteit</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="354"/>
        <source>Download quality</source>
        <translation>Download kwaliteit</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="320"/>
        <source>Start downloads</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="441"/>
        <source>Appearance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="466"/>
        <source>System</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="474"/>
        <source>Download location</source>
        <translation>Download locatie</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="483"/>
        <source>Screen orientation</source>
        <translation>Scherm orientatie</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="336"/>
        <source>Media player</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="193"/>
        <location filename="../SettingsDialog.qml" line="458"/>
        <location filename="../SettingsDialog.qml" line="460"/>
        <source>Language</source>
        <translation>Taal</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="40"/>
        <location filename="../SettingsDialog.qml" line="41"/>
        <source>High quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="41"/>
        <source>360p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="41"/>
        <source>480p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="41"/>
        <source>720p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="45"/>
        <source>Midnight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="47"/>
        <source>Russian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="47"/>
        <source>Portuguese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="48"/>
        <source>Most recent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="48"/>
        <source>Most viewed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="49"/>
        <source>Archive</source>
        <translation type="unfinished">Archief</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="49"/>
        <source>Latest subscription videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="50"/>
        <source>My uploads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="50"/>
        <source>My favourites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="136"/>
        <location filename="../SettingsDialog.qml" line="196"/>
        <source>Network Proxy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="160"/>
        <location filename="../SettingsDialog.qml" line="347"/>
        <source>Playback Quality</source>
        <translation>Afspeel Kwaliteit</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="163"/>
        <location filename="../SettingsDialog.qml" line="356"/>
        <source>Download Quality</source>
        <translation>Download Kwaliteit</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="166"/>
        <location filename="../SettingsDialog.qml" line="322"/>
        <source>Start Downloads</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="172"/>
        <location filename="../SettingsDialog.qml" line="372"/>
        <source>Category Feed One</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="175"/>
        <location filename="../SettingsDialog.qml" line="381"/>
        <source>Category Feed Two</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="178"/>
        <location filename="../SettingsDialog.qml" line="390"/>
        <source>Order Category Videos By</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="184"/>
        <location filename="../SettingsDialog.qml" line="485"/>
        <source>Screen Orientation</source>
        <translation>Scherm Orientatie</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="187"/>
        <location filename="../SettingsDialog.qml" line="338"/>
        <source>Media Player</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="229"/>
        <source>Your facebook token has been deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="232"/>
        <source>Database error. Unable to delete facebook token</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="362"/>
        <source>YouTube categories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="370"/>
        <source>Category feed one</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="379"/>
        <source>Category feed two</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="388"/>
        <source>Order category videos by</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="422"/>
        <source>Social networks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="433"/>
        <source>Delete facebook token</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="499"/>
        <source>Widget</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="507"/>
        <source>Feed one</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="516"/>
        <source>Feed two</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="525"/>
        <source>Feed three</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="534"/>
        <source>Feed four</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="40"/>
        <location filename="../SettingsDialog.qml" line="41"/>
        <source>Mobile</source>
        <translation>Mobiele kwaliteit</translation>
    </message>
    <message>
        <source>High Quality</source>
        <translation type="obsolete">Hoge Kwaliteit</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="42"/>
        <source>Automatically</source>
        <translation>Automatisch</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="42"/>
        <source>Manually</source>
        <translation>Handmatig</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="43"/>
        <source>On</source>
        <translation>Aan</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="43"/>
        <source>Off</source>
        <translation>Uit</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="44"/>
        <source>Automatic</source>
        <translation>Automatisch</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="44"/>
        <source>Landscape</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="44"/>
        <source>Portrait</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="45"/>
        <source>Light</source>
        <translation>Licht</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="45"/>
        <source>Dark</source>
        <translation>Donker</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="46"/>
        <source>English</source>
        <translation>Engels</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="46"/>
        <source>German</source>
        <translation>Duits</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="46"/>
        <source>Finnish</source>
        <translation>Fins</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="46"/>
        <source>Italian</source>
        <translation>Italiaans</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="46"/>
        <source>Dutch</source>
        <translation>Nederlands</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="47"/>
        <source>Polish</source>
        <translation>Pools</translation>
    </message>
    <message>
        <source>Queued</source>
        <translation type="obsolete">Wachtrij</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation type="obsolete">Pause</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="121"/>
        <source>Your settings have been saved</source>
        <translation>Uw instellingen zijn opgeslagen</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="126"/>
        <location filename="../SettingsDialog.qml" line="169"/>
        <source>Download Path</source>
        <translation>Download Pad</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="128"/>
        <source>Download Location</source>
        <translation>Download Locatie</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="181"/>
        <location filename="../SettingsDialog.qml" line="406"/>
        <source>Safe Search</source>
        <translation>Veilig Zoeken</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="190"/>
        <location filename="../SettingsDialog.qml" line="449"/>
        <location filename="../SettingsDialog.qml" line="451"/>
        <source>Theme</source>
        <translation>Thema</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="199"/>
        <location filename="../SettingsDialog.qml" line="509"/>
        <source>Widget Feed One</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="202"/>
        <location filename="../SettingsDialog.qml" line="518"/>
        <source>Widget Feed Two</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="205"/>
        <location filename="../SettingsDialog.qml" line="527"/>
        <source>Widget Feed Three</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="208"/>
        <location filename="../SettingsDialog.qml" line="536"/>
        <source>Widget Feed Four</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="303"/>
        <source>Network</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="311"/>
        <source>Network proxy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="328"/>
        <source>Media</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="396"/>
        <source>YouTube searches</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="404"/>
        <source>Safe search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="312"/>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="415"/>
        <source>Clear saved searches</source>
        <translation>Verwijder opgeslagen zoekopdrachten</translation>
    </message>
</context>
<context>
    <name>Sharing</name>
    <message>
        <location filename="../../../sharing.cpp" line="78"/>
        <source>Error - Server repsonse is: </source>
        <translation>Fout - Antwoord van de server is:</translation>
    </message>
</context>
<context>
    <name>SubscriptionsView</name>
    <message>
        <location filename="../SubscriptionsView.qml" line="34"/>
        <source>Latest Subscriptions Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SubscriptionsView.qml" line="41"/>
        <source>You have unsubscribed to this channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You have unsubscribed to &apos;</source>
        <translation type="obsolete">U heeft zich afgemeld voor &apos;</translation>
    </message>
    <message>
        <source>Latest Subscription Videos</source>
        <translation type="obsolete">Nieuwste video&apos;s van u Abonnementen</translation>
    </message>
    <message>
        <location filename="../SubscriptionsView.qml" line="85"/>
        <source>No subscriptions found</source>
        <translation>Geen Abonnementen gevonden</translation>
    </message>
</context>
<context>
    <name>UploadDialog</name>
    <message>
        <location filename="../UploadDialog.qml" line="70"/>
        <source>Cars &amp; Vehicles</source>
        <translation>Auto&apos;s &amp; Voertuigen</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="70"/>
        <source>Comedy</source>
        <translation>Komedie</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="71"/>
        <source>Education</source>
        <translation>Onderwijs</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="13"/>
        <location filename="../UploadDialog.qml" line="71"/>
        <source>Entertainment</source>
        <translation></translation>
    </message>
    <message>
        <source>Film and Animation</source>
        <translation type="obsolete">Film en Animatie</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="72"/>
        <source>Gaming</source>
        <translation>Gaming</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="72"/>
        <source>Film &amp; Animation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="73"/>
        <source>Howto &amp; Style</source>
        <translation>Zo-doe-je-dat &amp; stijl</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="73"/>
        <source>Music</source>
        <translation>Muziek</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="73"/>
        <source>News &amp; Politics</source>
        <translation>Nieuws &amp; Politiek</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="74"/>
        <source>Non-profits &amp; Activism</source>
        <translation>Non-profit &amp; activisme</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="74"/>
        <source>People &amp; Blogs</source>
        <translation>Mensen &amp; blogs</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="75"/>
        <source>Pets &amp; Animals</source>
        <translation>Huisdieren &amp; dieren</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="75"/>
        <source>Science &amp; Technology</source>
        <translation>Wetenschap &amp; technologie</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="76"/>
        <source>Sport</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="76"/>
        <source>Travel &amp; Events</source>
        <translation>Reizen &amp; evenementen</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="29"/>
        <location filename="../UploadDialog.qml" line="220"/>
        <source>Category</source>
        <translation>Categorie</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="118"/>
        <source>Upload Video</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="143"/>
        <source>File</source>
        <translation>Bestand</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="152"/>
        <location filename="../UploadDialog.qml" line="228"/>
        <source>None chosen</source>
        <translation>Geen gekozen</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="168"/>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="181"/>
        <source>Description (optional)</source>
        <translation>Beschrijving (optioneel)</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="193"/>
        <source>Tags (seperated by commas)</source>
        <translation>Labels (gescheiden door komma&apos;s)</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="206"/>
        <source>Private?</source>
        <translation>Privé?</translation>
    </message>
</context>
<context>
    <name>UploadProgressDialog</name>
    <message>
        <location filename="../UploadProgressDialog.qml" line="6"/>
        <source>Starting upload</source>
        <translation>Starten van de upload</translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="30"/>
        <source>Upload Progress</source>
        <translation>Upload vooruitgang</translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="42"/>
        <source>Filename</source>
        <translation>Bestandnaam</translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="57"/>
        <source>Title</source>
        <translation>titel</translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="91"/>
        <source>Abort</source>
        <translation>Stoppen</translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="91"/>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="91"/>
        <location filename="../UploadProgressDialog.qml" line="97"/>
        <location filename="../UploadProgressDialog.qml" line="115"/>
        <source>Upload is in progress</source>
        <translation>Upload is bezig</translation>
    </message>
</context>
<context>
    <name>UserInfoDialog</name>
    <message>
        <location filename="../UserInfoDialog.qml" line="106"/>
        <source>Profile</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="152"/>
        <source>Uploads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="158"/>
        <source>Subscribers</source>
        <translation>Abonnees</translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="178"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="184"/>
        <source>Age</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="197"/>
        <location filename="../UserInfoDialog.qml" line="215"/>
        <location filename="../UserInfoDialog.qml" line="221"/>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="203"/>
        <source>Gender</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="209"/>
        <source>Location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="215"/>
        <source>Male</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="215"/>
        <source>Female</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="236"/>
        <source>About</source>
        <translation type="unfinished">Info</translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="254"/>
        <source>No info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="269"/>
        <source>Unsubscribe</source>
        <translation type="unfinished">Afmelden</translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="269"/>
        <source>Subscribe</source>
        <translation type="unfinished">Aanmelden</translation>
    </message>
</context>
<context>
    <name>UserVideosView</name>
    <message>
        <location filename="../UserVideosView.qml" line="127"/>
        <source>You have subscribed to &apos;</source>
        <translation>U heeft zich aangemeld voor &apos;</translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="131"/>
        <source>You have unsubscribed to &apos;</source>
        <translation>U heeft zich afgemeld voor &apos;</translation>
    </message>
    <message>
        <source>Add to favourites</source>
        <translation type="obsolete">Voeg toe aan Favorieten</translation>
    </message>
    <message>
        <source>Add to playlist</source>
        <translation type="obsolete">Voeg toe aan afspeellijst</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation type="obsolete">Kopiëren naar klembord</translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="151"/>
        <source>No videos found</source>
        <translation>Geen videos gevonden</translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="209"/>
        <source>Subscribers</source>
        <translation>Abonnees</translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="223"/>
        <source>Videos</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="246"/>
        <source>Unsubscribe</source>
        <translation>Afmelden</translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="246"/>
        <source>Subscribe</source>
        <translation>Aanmelden</translation>
    </message>
</context>
<context>
    <name>VideoInfoView</name>
    <message>
        <location filename="../VideoInfoView.qml" line="15"/>
        <source>No description</source>
        <translation>Geen beschrijving</translation>
    </message>
    <message>
        <source>Your comment has been added</source>
        <translation type="obsolete">Uw commentaar is toe gevoegd</translation>
    </message>
    <message>
        <source>Your rating has been added</source>
        <translation type="obsolete">Uw beoordeling is toe gevoegd</translation>
    </message>
    <message>
        <source>Video shared on facebook</source>
        <translation type="obsolete">Video gedeeld op facebook</translation>
    </message>
    <message>
        <source>Add to favourites</source>
        <translation type="obsolete">Voeg toe aan favorieten</translation>
    </message>
    <message>
        <source>Add to playlist</source>
        <translation type="obsolete">Voeg toe aan afspeellijst</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation type="obsolete">Kopiëren naar het klembord</translation>
    </message>
    <message>
        <source>Share via facebook</source>
        <translation type="obsolete">Delen via facebook</translation>
    </message>
    <message>
        <source>You are not signed in to a YouTube account</source>
        <translation type="obsolete">Je bent niet ingelogd me teen YouTube account</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="240"/>
        <source>Info</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="278"/>
        <source>Comments</source>
        <translation>Reacties</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="316"/>
        <source>Related</source>
        <translation>Gerelateerde</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="401"/>
        <location filename="../VideoInfoView.qml" line="404"/>
        <source>By </source>
        <translation>Door</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="403"/>
        <location filename="../VideoInfoView.qml" line="406"/>
        <source> on </source>
        <translation> op </translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="474"/>
        <source>Views</source>
        <translation>Bekeken</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="488"/>
        <source>Description</source>
        <translation>Beschrijving</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="504"/>
        <source>Tags</source>
        <translation>Labels</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="514"/>
        <source>No tags</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="583"/>
        <source>No comments</source>
        <translation>Geen reacties</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="583"/>
        <source> comments</source>
        <translation> reacties</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="697"/>
        <source>No related videos</source>
        <translation>Geen gerelateerde videos</translation>
    </message>
</context>
<context>
    <name>VideoListDelegate</name>
    <message>
        <location filename="../VideoListDelegate.qml" line="51"/>
        <source>By </source>
        <translation>Door </translation>
    </message>
    <message>
        <location filename="../VideoListDelegate.qml" line="51"/>
        <source> on </source>
        <translation> op </translation>
    </message>
    <message>
        <location filename="../VideoListDelegate.qml" line="101"/>
        <source>Views</source>
        <translation>Bekeken</translation>
    </message>
</context>
<context>
    <name>VideoListView</name>
    <message>
        <source>Add to favourites</source>
        <translation type="obsolete">Voeg toe aan favorieten</translation>
    </message>
    <message>
        <source>Add to playlist</source>
        <translation type="obsolete">Voeg toe aan afspeellijst</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation type="obsolete">Kopiëren naar het klembord</translation>
    </message>
    <message>
        <location filename="../VideoListView.qml" line="79"/>
        <source>Video(s) deleted from favourites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../VideoListView.qml" line="101"/>
        <source>No videos found</source>
        <translation>Geen video&apos;s gevonden</translation>
    </message>
</context>
<context>
    <name>VideoPlaybackView</name>
    <message>
        <source>Error: Unable to retrieve video</source>
        <translation type="obsolete">Fout: Kan geen video ophalen</translation>
    </message>
    <message>
        <location filename="../VideoPlaybackView.qml" line="233"/>
        <location filename="../VideoPlaybackView.qml" line="422"/>
        <location filename="../VideoPlaybackView.qml" line="1024"/>
        <source>Loading...</source>
        <translation type="unfinished">Laden...</translation>
    </message>
    <message>
        <location filename="../VideoPlaybackView.qml" line="731"/>
        <source>Info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../VideoPlaybackView.qml" line="769"/>
        <source>Comments</source>
        <translation type="unfinished">Reacties</translation>
    </message>
    <message>
        <location filename="../VideoPlaybackView.qml" line="807"/>
        <source>Playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../VideoPlaybackView.qml" line="889"/>
        <source>By </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../VideoPlaybackView.qml" line="889"/>
        <source> on </source>
        <translation type="unfinished"> op </translation>
    </message>
    <message>
        <location filename="../VideoPlaybackView.qml" line="889"/>
        <source>Added on </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../VideoPlaybackView.qml" line="954"/>
        <source>Views</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../VideoPlaybackView.qml" line="968"/>
        <source>Description</source>
        <translation type="unfinished">Beschrijving</translation>
    </message>
    <message>
        <location filename="../VideoPlaybackView.qml" line="976"/>
        <source>No description</source>
        <translation type="unfinished">Geen beschrijving</translation>
    </message>
    <message>
        <location filename="../VideoPlaybackView.qml" line="1001"/>
        <source>No comments</source>
        <translation type="unfinished">Geen reacties</translation>
    </message>
    <message>
        <location filename="../VideoPlaybackView.qml" line="1001"/>
        <source> comments</source>
        <translation type="unfinished"> reacties</translation>
    </message>
</context>
<context>
    <name>Widget</name>
    <message>
        <source>No videos found</source>
        <translation type="obsolete">Geen video gevonden</translation>
    </message>
</context>
<context>
    <name>YouTube</name>
    <message>
        <location filename="../../../youtube.cpp" line="43"/>
        <source>Error obtaining access token</source>
        <translation>Fout bij het verkijgen van een toegangs certificaat</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="54"/>
        <source>Authentication failed</source>
        <translation>Authenticatie is mislukt</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="58"/>
        <source>You are signed in to YouTube as &apos;</source>
        <translation>U bent aangemeld bij YouTube als &apos;</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="120"/>
        <location filename="../../../youtube.cpp" line="229"/>
        <source>Error - Server repsonse is: </source>
        <translation>Error - Server antwoord is:</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="170"/>
        <location filename="../../../youtube.cpp" line="178"/>
        <source>Upload aborted</source>
        <translation>Upload gestopt</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="185"/>
        <source>Upload interrupted. Attempting to resume...</source>
        <translation>Upload onderbroken. Probeert te hervatten ...</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="189"/>
        <source>Upload failed</source>
        <translation>Upload mislukt</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="195"/>
        <source>Upload is completed</source>
        <translation>Upload is voltooid</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="400"/>
        <source>Error: Unable to retrieve video</source>
        <translation>Fout: Kan geen video ophalen</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Dark</source>
        <translation type="obsolete">Donker</translation>
    </message>
    <message>
        <source>Light</source>
        <translation type="obsolete">Licht</translation>
    </message>
    <message>
        <source>Video(s) added to download queue</source>
        <translation type="obsolete">Video(s) toe gevoegd aan download wachtrij</translation>
    </message>
    <message>
        <location filename="../main.qml" line="462"/>
        <source>Video(s) already in download queue</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main.qml" line="463"/>
        <source>Audio track(s) added to download queue</source>
        <translation>Audio track(s) toe gevoegd aan download wachtrij</translation>
    </message>
    <message>
        <location filename="../main.qml" line="464"/>
        <source>Audio track(s) already in download queue</source>
        <translation></translation>
    </message>
    <message>
        <source>Video added to favourites</source>
        <translation type="obsolete">Video toe gevoegd aan favorieten</translation>
    </message>
    <message>
        <source>Video added to playlist</source>
        <translation type="obsolete">Video toe gevoegd aan afspeellijst</translation>
    </message>
    <message>
        <location filename="../main.qml" line="459"/>
        <source>New playlist created</source>
        <translation>Nieuwe afspeellijst gemaakt</translation>
    </message>
    <message>
        <location filename="../main.qml" line="285"/>
        <source>Converting</source>
        <translation>Omzetten</translation>
    </message>
    <message>
        <location filename="../main.qml" line="270"/>
        <source>Conversion of &apos;</source>
        <translation>Conversie van &apos;</translation>
    </message>
    <message>
        <location filename="../main.qml" line="453"/>
        <source>Your rating has been added</source>
        <translation type="unfinished">Uw beoordeling is toe gevoegd</translation>
    </message>
    <message>
        <location filename="../main.qml" line="455"/>
        <source>Your comment has been added</source>
        <translation type="unfinished">Uw commentaar is toe gevoegd</translation>
    </message>
    <message>
        <location filename="../main.qml" line="460"/>
        <source>Video shared on facebook</source>
        <translation type="unfinished">Video gedeeld op facebook</translation>
    </message>
    <message>
        <location filename="../main.qml" line="461"/>
        <source>Videos(s) added to download queue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="465"/>
        <source>You are not signed in to a YouTube account</source>
        <translation type="unfinished">Je bent niet ingelogd me teen YouTube account</translation>
    </message>
    <message>
        <location filename="../main.qml" line="466"/>
        <source>No YouTube account found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="467"/>
        <source>Use the cuteTube Player to access this feature</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="34"/>
        <source>Cars &amp; Vehicles</source>
        <translation type="unfinished">Auto&apos;s &amp; Voertuigen</translation>
    </message>
    <message>
        <location filename="../main.qml" line="34"/>
        <source>Comedy</source>
        <translation type="unfinished">Komedie</translation>
    </message>
    <message>
        <location filename="../main.qml" line="35"/>
        <source>Education</source>
        <translation type="unfinished">Onderwijs</translation>
    </message>
    <message>
        <location filename="../main.qml" line="35"/>
        <source>Entertainment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="36"/>
        <source>Film &amp; Animation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="36"/>
        <source>Gaming</source>
        <translation type="unfinished">Gaming</translation>
    </message>
    <message>
        <location filename="../main.qml" line="37"/>
        <source>Howto &amp; Style</source>
        <translation type="unfinished">Zo-doe-je-dat &amp; stijl</translation>
    </message>
    <message>
        <location filename="../main.qml" line="37"/>
        <source>Music</source>
        <translation type="unfinished">Muziek</translation>
    </message>
    <message>
        <location filename="../main.qml" line="37"/>
        <source>News &amp; Politics</source>
        <translation type="unfinished">Nieuws &amp; Politiek</translation>
    </message>
    <message>
        <location filename="../main.qml" line="38"/>
        <source>Non-profits &amp; Activism</source>
        <translation type="unfinished">Non-profit &amp; activisme</translation>
    </message>
    <message>
        <location filename="../main.qml" line="38"/>
        <source>People &amp; Blogs</source>
        <translation type="unfinished">Mensen &amp; blogs</translation>
    </message>
    <message>
        <location filename="../main.qml" line="39"/>
        <source>Pets &amp; Animals</source>
        <translation type="unfinished">Huisdieren &amp; dieren</translation>
    </message>
    <message>
        <location filename="../main.qml" line="39"/>
        <source>Science &amp; Technology</source>
        <translation type="unfinished">Wetenschap &amp; technologie</translation>
    </message>
    <message>
        <location filename="../main.qml" line="40"/>
        <source>Sport</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="40"/>
        <source>Travel &amp; Events</source>
        <translation type="unfinished">Reizen &amp; evenementen</translation>
    </message>
    <message>
        <location filename="../main.qml" line="42"/>
        <source>Relevance</source>
        <translation type="unfinished">Relevantie</translation>
    </message>
    <message>
        <location filename="../main.qml" line="42"/>
        <source>Date</source>
        <translation type="unfinished">Datum</translation>
    </message>
    <message>
        <location filename="../main.qml" line="42"/>
        <source>Views</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="42"/>
        <source>Rating</source>
        <translation type="unfinished">Beoordeling</translation>
    </message>
    <message>
        <location filename="../main.qml" line="454"/>
        <source>You cannot rate your own videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="456"/>
        <source>Video(s) added to favourites</source>
        <translation>Video(s) toe gevoegd aan favorieten</translation>
    </message>
    <message>
        <location filename="../main.qml" line="457"/>
        <source>Video already in favourites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="458"/>
        <source>Video(s) added to playlist</source>
        <translation>Video(s) toe gevoegd aan afspeellijst</translation>
    </message>
    <message>
        <location filename="../main.qml" line="468"/>
        <source>Unable to play videos at 360p quality or higher</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="270"/>
        <source>&apos; failed</source>
        <translation>&apos; mislukt</translation>
    </message>
    <message>
        <source>Mobile</source>
        <translation type="obsolete">Mobiele kwaliteit</translation>
    </message>
    <message>
        <location filename="../main.qml" line="285"/>
        <source>Queued</source>
        <translation>Wachtrij</translation>
    </message>
    <message>
        <location filename="../main.qml" line="285"/>
        <source>Paused</source>
        <translation>Gepauzeerd</translation>
    </message>
    <message>
        <location filename="../main.qml" line="285"/>
        <source>Downloading</source>
        <translation>Downloaden</translation>
    </message>
    <message>
        <location filename="../main.qml" line="285"/>
        <source>Failed</source>
        <translation>Mislukt</translation>
    </message>
    <message>
        <location filename="../main.qml" line="41"/>
        <source>Most Recent</source>
        <translation>Meest Recent</translation>
    </message>
    <message>
        <location filename="../main.qml" line="41"/>
        <source>Most Viewed</source>
        <translation>Meest Bekeken</translation>
    </message>
</context>
<context>
    <name>mainscripts</name>
    <message>
        <source>My Channel</source>
        <translation type="obsolete">Mijn Kanaal</translation>
    </message>
    <message>
        <source>Archive</source>
        <translation type="obsolete">Archief</translation>
    </message>
    <message>
        <source>My Playlists</source>
        <translation type="obsolete">Mijn Afspeellijst</translation>
    </message>
    <message>
        <source>My Subscriptions</source>
        <translation type="obsolete">Mijn Abonnementen</translation>
    </message>
    <message>
        <source>Video Playback</source>
        <translation type="obsolete">Video Afspelen</translation>
    </message>
    <message>
        <source>date</source>
        <translation type="obsolete">datum</translation>
    </message>
    <message>
        <source>views</source>
        <translation type="obsolete">bekeken</translation>
    </message>
    <message>
        <source>relevance</source>
        <translation type="obsolete">relevantie</translation>
    </message>
    <message>
        <source>rating</source>
        <translation type="obsolete">beoordelingen</translation>
    </message>
    <message>
        <source>Search </source>
        <translation type="obsolete">Zoeken </translation>
    </message>
</context>
<context>
    <name>settings</name>
    <message>
        <source>High Quality</source>
        <translation type="obsolete">Hoge Kwaliteit</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation type="obsolete">Gepauzeerd</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation type="obsolete">Automatisch</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="obsolete">Datum</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation type="obsolete">Donker</translation>
    </message>
    <message>
        <source>English</source>
        <translation type="obsolete">Engels</translation>
    </message>
</context>
</TS>
